@@ -33,7 +33,7 @@ __all__ = ['get_model', 'Model', 'TimeSeriesModel', 'StretchModel',
 cosmology.set_current(cosmology.WMAP9)
 HC_ERG_AA = const.h.cgs.value * const.c.to(u.AA / u.s).value
 
-def get_model(name, version=None):
+def get_model(name, version=None, copy=False):
     """Retrieve a model from the registry by name.
 
     Parameters
@@ -43,11 +43,25 @@ def get_model(name, version=None):
     version : str, optional
         Version identifier for models with multiple versions. Default is
         `None` which corresponds to the latest, or only, version.
+    copy : bool, optional
+        If True and if `name` is already a Model instance, return a copy of
+        it by calling ``name()``. (If `name` is a str a copy of the instance
+        in the registry is always returned, regardless of the value of this
+        parameter.) Default is False.
     """
     
-    # Call the one in the registry to create a copy and keep the registry
-    # copy pristine.
-    return registry.retrieve(Model, name, version=version)()
+    # If we need to retrieve from the registry, we want to return a shallow
+    # copy, in order to keep the copy in the registry "pristene". However, we
+    # *don't* want a shallow copy otherwise. Therefore,
+    # we need to check if `name` is already an instance of Model before 
+    # going to the registry, so we know whether or not to make a shallow copy.
+    if isinstance(name, Model):
+        if copy:
+            return name()
+        else:
+            return name
+    else:
+        return registry.retrieve(Model, name, version=version)()
 
 
 class Model(object):
@@ -110,6 +124,8 @@ class Model(object):
         # Below, when `self._refm` and `self._distmod` might have changed, we
         # set them to `None` so that they are recalculated as needed.
 
+        recalc_fscale = False
+
         if 'z' in params and self._params['z'] != params['z']:
             self._distmod = None
 
@@ -171,7 +187,13 @@ class Model(object):
                 raise ValueError("cannot set absolute magnitude when distance "
                                  "modulus is unknown (when either redshift or "
                                  "cosmology is None)")
-            self._distmod = self._cosmo.distmod(self._params['z'])
+
+            # TODO: remove this hack once astropy v0.3 is released
+            dm = self._cosmo.distmod(self._params['z'])
+            try:
+                self._distmod = dm.value  # dm is Quantity in astropy v0.3+
+            except AttributeError:
+                self._distmod = dm # dm is float in astropy v0.2.x
 
         self._params['m'] = self._params['mabs'] + self._distmod
         self._set_fscale_from_m()
